Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(800)

Unified Diff: ash/system/rotation/tray_rotation_lock.h

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/system/rotation/tray_rotation_lock.h
diff --git a/ash/system/rotation/tray_rotation_lock.h b/ash/system/rotation/tray_rotation_lock.h
index 1dbe7a7fc3816eaf294df2e05f39cf675258e9fa..fdfc5a2c317946aa111cec1ff891ee4b53a3bb6c 100644
--- a/ash/system/rotation/tray_rotation_lock.h
+++ b/ash/system/rotation/tray_rotation_lock.h
@@ -32,8 +32,8 @@ class ASH_EXPORT TrayRotationLock
views::View* CreateDefaultView(LoginStatus status) override;
// ShellObserver:
- void OnMaximizeModeStarted() override;
- void OnMaximizeModeEnded() override;
+ void OnTabletModeStarted() override;
+ void OnTabletModeEnded() override;
// TrayImageItem:
void DestroyTrayView() override;
@@ -48,7 +48,7 @@ class ASH_EXPORT TrayRotationLock
// Update tray image based on whether user rotation lock is enabled.
void UpdateTrayImage();
// True if |on_primary_display_|, maximize mode is enabled.
bool ShouldBeVisible();
// True if this is owned by a SystemTray on the primary display.
@@ -48,7 +48,7 @@ class ASH_EXPORT TrayRotationLock
// Update tray image based on whether user rotation lock is enabled.
void UpdateTrayImage();
- // True if |on_primary_display_|, maximize mode is enabled.
+ // True if |on_primary_display_|, tablet mode is enabled.
bool ShouldBeVisible();
// True if this is owned by a SystemTray on the primary display.

Powered by Google App Engine
This is Rietveld 408576698